@@ -1,9 +1,9 @@
 package App::ColorThemeUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-08'; # DATE
+our $DATE = '2020-06-09'; # DATE
 our $DIST = 'App-ColorThemeUtils'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -80,7 +80,7 @@ sub show_color_theme_swatch {
     my $reset = Color::ANSI::Util::ansi_reset();
     for my $item_name (@item_names) {
         my $empty_bar = " " x $width;
-        my $color0 = $ctheme->get_color($item_name);
+        my $color0 = $ctheme->get_item_color($item_name);
         my $color_summary = ref $color0 eq 'HASH' && defined($color0->{summary}) ?
             String::Pad::pad($color0->{summary}, $width, "center", " ", 1) : undef;
         my $fg_color = ref $color0 eq 'HASH' ? $color0->{fg} : $color0;
@@ -121,7 +121,7 @@ App::ColorThemeUtils - CLI utilities related to color themes
 
 =head1 VERSION
 
-This document describes version 0.005 of App::ColorThemeUtils (from Perl distribution App-ColorThemeUtils), released on 2020-06-08.
+This document describes version 0.006 of App::ColorThemeUtils (from Perl distribution App-ColorThemeUtils), released on 2020-06-09.
 
 =head1 DESCRIPTION
 
